WebCacheClearPlatform class abstract

Inheritance
  • Object
  • PlatformInterface
  • WebCacheClearPlatform
Implementers

Constructors

WebCacheClearPlatform()
Constructs a WebCacheClearPlatform.

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

checkAppVersion(String appVersion) → Future<void>
clearCache() → Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

instance ↔ WebCacheClearPlatform
The default instance of WebCacheClearPlatform to use.
getter/setter pair