WebCacheClearWeb class

A web implementation of the WebCacheClearPlatform of the WebCacheClear plugin.

Inheritance

Constructors

WebCacheClearWeb()
Constructs a WebCacheClearWeb

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
window ↔ Window
A getter for the window object, settable for testing purposes.asd
getter/setter pair

Methods

checkAppVersion(String appVersion) → Future<void>
Checks the app version and clears cache if it's outdated.
override
clearCache() → Future<void>
Clears the browser's Cache Storage.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

registerWith(Registrar registrar) → void